loc_est_bw: Bootstrap bandwidth selection for the local linear frontier estimator
Description
Computes the optimal bootstrap bandwidth proposed by Hall and Park (2004) for the local linear frontier estimator
Usage
loc_est_bw(xtab, ytab, x, hini, B = 5)
Arguments
xtab
numeric vectors containing the observed inputs $x_1,\ldots,x_n$
ytab
numeric vectors of the same length as xtab containing the observed outputs $y_1,\ldots,y_n$
x
a numeric vector of evaluation points in which the estimator is to be computed
hini
the initial bandwidth at which the local linear estimate will be computed
B
number of bootstrap replications
Value
Returns the optimal bootstrap bandwidth
Details
For a detailed description of the bootstrap procedure, see Hall and Park (2004)
References
Hall, P. and Park, B.U. (2004). Bandwidth choice for local polynomial estimation of smooth boundaries. Journal of Multivariate Analysis, 91 (2), 240-261.
data("nuclear")
x <- seq(min(nuclear$xtab), max(nuclear$xtab), length.out=1001)
# loc_est_bw(nuclear$xtab, nuclear$ytab, x, hini=40, B=100)# long computational time # returns the value 79.12