quad_spline_est_kn(xtab, ytab, x, cv, krange = 1:20, type = "AIC")xtab containing the observed outputs $y_1,\ldots,y_n$quad_spline_est).
Because the number of knots $k_n$ determines the complexity of the spline approximation,
its choice may then be viewed as model selection
through the minimization of the following two information criteria:
$$AIC(k) = \log \left( \sum_{i=1}^{n} |y_i- \hat \varphi_n(x_i)|\right) + 2(k+2)/n,$$
$$BIC(k) = \log \left( \sum_{i=1}^{n} |y_i- \hat \varphi_n(x_i)|\right) + \log n \cdot (k+2)/n.$$
The first one (option type = "AIC") is similar to the famous Akaike information criterion (Akaike, 1973) and the second one
(option type = "BIC") to the Bayesian information criterion (Schwartz, 1978).
A small number of knots is typically needed as elucidated by the asymptotic theory.
For the implementation of the monotone and concave spline estimator $\hat\varphi^{\star}_n$,
just apply the same scheme as above by replacing the FDH points $(\mathcal{X}_{\ell},\mathcal{Y}_{\ell})$
with the DEA points $(\mathcal{X}^*_{\ell},\mathcal{Y}^*_{\ell})$ (see dea_est).quad_spline_estdata("green")
x <- seq(min(log(green$COST)), max(log(green$COST)), length.out=1001)
quad_spline_est_kn(log(green$COST), log(green$OUTPUT), x, cv=1, type="AIC")
quad_spline_est_kn(log(green$COST), log(green$OUTPUT), x, cv=1, type="BIC")Run the code above in your browser using DataLab